package environment.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

import environment.event.DetektorListener;

/**
 * Interface for remote object 'Detektor'. Use this
 * object to refer to detectors in the embedded system. 
 * You can retrieve references to
 * Detektor remote objects through the 
 * {@link environment.rmi.Verkehrsleitsystem}
 * class (will be available when Interface to simulator is introduced
 * in 'Implementierung III'). You need to add your own implementation of the 
 * {@link environment.event.DetektorListener} interface
 * to be notified of 
 * {@link environment.event.DetektorEvent}, i.e. when a vehicle
 * was detected.
 *
 * @author Andreas Metzger
 * @version 1.1
 */

public interface Detektor extends Remote {

	/** Adds an implementation of DetektorListener whose
	 *  vehicleDetected() method is invoked when
	 *  a car is detected.
	 * @param dl DetektorListener for DetektorEvents of this Detektor.
	 * @throws RemoteException All RMI objects throw this exception.
	 */
	public void addDetektorListener(DetektorListener dl) throws RemoteException;

	/** Removes a DetektorListener.
	 * @param dl DetektorListener for DetektorEvents of this Detektor.
	 * @throws RemoteException All RMI objects throw this exception.
	 */
	public void removeDetektorListener(DetektorListener dl) throws RemoteException;
}
